@@ -64,6 +64,7 @@ public slots:
   // Ui callbacks
   void onEditAccounts();
   void onAliasClicked(const QString& alias);
+  void onEnableRotation();
 };
 
 //////////////////////////////////////////////////////////////////////////
@@ -78,8 +79,11 @@ void MainWindowPrivate::init()
   startWidget = new StartWidget(self);
   startWidget->setAccounts(accounts);
 
+  messageWidget = new MessageWidget(self, Qt::Window);
+
 #ifdef Q_WS_MAEMO_5
   self->setAttribute(Qt::WA_Maemo5StackedWindow);
+  messageWidget->setAttribute(Qt::WA_Maemo5StackedWindow);
 #endif // Q_WS_MAEMO_5
 
   // Set the message widget as central widget
@@ -88,6 +92,7 @@ void MainWindowPrivate::init()
   // Setup the menu
   QMenu* menu = self->menuBar()->addMenu(QString());
   menu->addAction(tr("Accounts ..."), this, SLOT(onEditAccounts()));
+  menu->addAction(tr("Enable rotation"), this, SLOT(onEnableRotation()));
 
 #if !defined(Q_WS_S60) && !defined(Q_WS_MAEMO_5)
   // We have to set a window title, otherwise Windows won't show the menu
@@ -100,6 +105,16 @@ void MainWindowPrivate::init()
 
 //////////////////////////////////////////////////////////////////////////
 
+void MainWindowPrivate::onEnableRotation()
+{
+#ifdef Q_WS_MAEMO_5
+  self->setAttribute(Qt::WA_Maemo5AutoOrientation);
+  messageWidget->setAttribute(Qt::WA_Maemo5AutoOrientation);
+#endif // Q_WS_MAEMO_5
+}
+
+//////////////////////////////////////////////////////////////////////////
+
 void MainWindowPrivate::onEditAccounts()
 {
   // Show the accounts dialog
@@ -120,15 +135,6 @@ void MainWindowPrivate::onAliasClicked(const QString& alias)
   // Find the provider interface
   ProviderInterface* provider = accounts->providerForAlias(alias);
 
-  if ( !messageWidget )
-  {
-    messageWidget = new MessageWidget(self, Qt::Window);
-
-#ifdef Q_WS_MAEMO_5
-    messageWidget->setAttribute(Qt::WA_Maemo5StackedWindow);
-#endif // Q_WS_MAEMO_5
-  }
-
   // Make the message view prettier
   ProviderInfo info = accounts->providerInfoForAlias(alias);
   messageWidget->setWindowTitle( tr("Send SMS with %1").arg(info.visibleName()) );
