@@ -21,6 +21,7 @@
 
 // Local includes
 #include "messagewidget.hpp"
+#include "orientationhelper.hpp"
 #include "providers/providerinterface.hpp"
 #include "providers/contacts.h"
 #include "providers/messagetypemodel.hpp"
@@ -56,8 +57,13 @@ public:
   QPointer<ProviderInterface> provider;
   MessageTypeModel messageTypeModel;
 
+  OrientationHelper orientationHelper;
+
+  QVBoxLayout* portraitLayout;
+
   // Functions
   void init();
+  QLayout* setupPortraitLayout();
 
 public slots:
   void updateUi();
@@ -78,9 +84,16 @@ public slots:
 
 void MessageWidgetPrivate::init()
 {
+  // Setup the orientation helper
+  orientationHelper.setWidget(self);
+
   // Setup the ui
   ui.setupUi(self);
 
+  // Setup the layouts
+  orientationHelper.setLandscapeLayout(ui.verticalLayout);
+  orientationHelper.setPortraitLayout( setupPortraitLayout() );
+
   QMenuBar* menuBar = new QMenuBar(self);
   QMenu* menu = menuBar->addMenu( QString() );
   menu->addAction(tr("Clear receivers"), this, SLOT(onClearReceivers()));
@@ -101,6 +114,29 @@ void MessageWidgetPrivate::init()
 
 //////////////////////////////////////////////////////////////////////////
 
+QLayout* MessageWidgetPrivate::setupPortraitLayout()
+{
+  portraitLayout = new QVBoxLayout;
+
+  QHBoxLayout* topBox = new QHBoxLayout;
+  topBox->addWidget(ui.chooseContactButton);
+  topBox->addWidget(ui.contactEdit);
+  portraitLayout->addLayout(topBox);
+
+  portraitLayout->addWidget(ui.messageText);
+  portraitLayout->addWidget(ui.balanceLabel);
+
+  QHBoxLayout* bottomBox = new QHBoxLayout;
+  bottomBox->addWidget(ui.messageTypePicker);
+  bottomBox->addWidget(ui.messageInfoLabel);
+  bottomBox->addWidget(ui.sendButton);
+  portraitLayout->addLayout(bottomBox);
+
+  return portraitLayout;
+}
+
+//////////////////////////////////////////////////////////////////////////
+
 void MessageWidgetPrivate::updateUi()
 {
   QVariant messageTypeData = messageTypeModel.index(ui.messageTypePicker->currentIndex()).data(MessageTypeModel::MessageTypeRole);
