@@ -24,10 +24,6 @@
 
 // Local includes
 #include "providers/providerinterface.hpp"
-#include "providers/accountsmodel.hpp"
-
-// Global includes
-#include <QtGui/QWidget>
 
 // Forward declarations
 class MessageWidgetPrivate;
@@ -48,10 +44,6 @@ public:
   void setProvider(ProviderInterface* provider);
   ProviderInterface* provider() const;
 
-  /// Get/Set the accounts
-  void setAccounts(const AccountsPtr& accounts);
-  AccountsPtr accounts() const;
-
 protected:
   MessageWidgetPrivate* d;
 };
